@@ -232,7 +232,7 @@ is_valid.TT_meta <- function(dat){
 #' @export
 #'
 print.TT_meta <- function(x, ...){
-  name_width   <- max(unlist(lapply(names(x), nchar))) + 1
+  name_width   <- max(unlist(lapply(names(x), crayon::col_nchar))) + 1
   print_string <- paste0('%', name_width, 's: %s\n')
   padded_newline <- rep(' ', name_width + 2) %>%
     paste(collapse = '')
